# -*- coding: utf-8 -*-

from mootdx.reader import Reader, ExReader
from mootdx.market import LiveBars, ExLiveBars
import unittest

class TestLiveBars(unittest.TestCase):
    reader = None

    ##初始化工作
    def setUp(self):
        self.reader = Reader(tdxdir='/Volumes/BOOTCAMP/new_tdx')
    
    #退出清理工作
    def tearDown(self):
        pass
    
    #具体的测试用例，一定要以test开头
    def testDaily(self):
        self.assertTrue(self.reader.daily(stock='000001'))
        
        
    def testMinbar(self):
        self.assertTrue(self.reader.minbar(stock='000001'))
        
class TestExLiveBars(unittest.TestCase):
    reader = None

    ##初始化工作
    def setUp(self):
        self.reader = Reader(tdxdir='/Volumes/BOOTCAMP/new_tdx')
    
    #退出清理工作
    def tearDown(self):
        pass
    
    #具体的测试用例，一定要以test开头
    def testDaily(self):
        self.assertTrue(self.reader.daily(stock='000001'))
        
        
    def testMinbar(self):
        self.assertTrue(self.reader.minbar(stock='000001'))
        
if __name__ =='__main__':
    unittest.main()
# def test_daily():
# 	assert reader.daily(stock='000001') == True



# -*- coding: utf-8 -*-
from mootdx.reader import Reader, ExReader
from mootdx.market import LiveBars, ExLiveBars
import unittest

class TestLiveBars(unittest.TestCase):
    reader = None

    ##初始化工作
    def setUp(self):
        self.client = LiveBars()
    
    #退出清理工作
    def tearDown(self):
        del self.client
    
    #具体的测试用例，一定要以test开头
    def testBars(self):
        data = self.client.bars(symbol='000001')
        print(data)
        # self.assertTrue(data)
        
        
    # def testMinbar(self):
    #     self.assertTrue(self.client.minute(symbol='000001'))
        
if __name__ =='__main__':
    unittest.main()
# def test_daily():
# 	assert reader.daily(symbol='000001') == True



# -*- coding: utf-8 -*-
from pytdx.hq import TdxHq_API
from pytdx.exhq import TdxExHq_API

class LiveBars(object):
	"""股票市场实时行情"""
	client = None

	def __init__(self, **kwargs):
		self.client = TdxHq_API(**kwargs)
		self.client.connect()

	def __del__(self):
		self.client.disconnect()

	# K线
	def bars(self, symbol='000001', category='1', market='1', start='1', count='100'):
		data = self.client.get_security_bars(category, market, symbol, start, count)
		return self.client.to_df(data)

	# 分时数据
	def minute(self, market='1', symbol=''):
		data = self.client.get_minute_time_data(market, symbol)
		return self.client.to_df(data)

	def minute_his(self, market='1', symbol='', datetime='20161209'):
		data = self.client.get_history_minute_time_data(market, symbol, datetime)
		return self.client.to_df(data)

	def trans(self, market='1', symbol='', start='', end=''):
		data = self.client.get_transaction_data(market, symbol, symbol, end)
		return self.client.to_df(data)

	def trans_his(self, market='1', symbol='', start='', end='', date=''):
		data = self.client.get_history_transaction_data(market, symbol, start, end, symbol)
		return self.client.to_df(data)

	def company_category(self, market='1', symbol=''):
		data = self.client.get_company_info_category(market, symbol)
		return self.client.to_df(data)

	def company_content(self, market='1', symbol='', file='', start='', end=''):
		data = self.client.get_company_info_content(market, symbol, file, start, end)
		return self.client.to_df(data)

	def finance(self, market='1', symbol=''):
		data = self.client.get_finance_info(market, symbol)
		return self.client.to_df(data)

	def k(self, symbol='', start='', end=''):
		data = self.client.get_k_data(symbol, start, end)
		return self.client.to_df(data)

	def block(self, tofile="block.dat"):
		data = self.client.get_and_parse_block_info(tofile)
		return self.client.to_df(data)

class ExLiveBars(LiveBars):
	"""扩展市场实时行情"""
	def __init__(self, **kwargs):
		self.client = TdxExHq_API(auto_retry=True)
		self.client.connect()

	# K线
	def bars(self, symbol=''):
		data = self.client.get_security_bars(9, 0, symbol, 0, 10)
		return self.client.to_df(data)

	def markets(self):
		data = self.client.get_markets()
		return self.client.to_df(data)

	def instrument(self, limit=0, offset=100):
		data = self.client.get_instrument_info(limit, offset)
		return self.client.to_df(data)
		



# -*- coding: utf-8 -*-
from pytdx.reader import (
    TdxFileNotFoundException,
    TdxExHqDailyBarReader, 
    CustomerBlockReader,
    TdxLCMinBarReader,
    TdxDailyBarReader, 
    TdxMinBarReader,
    BlockReader
)
import os

# 股票市场
class Reader(object):
    """股票市场"""

    tdxdir = r'C:/new_tdx'

    def __init__(self, tdxdir=None):
        super(Reader, self).__init__()
        self.tdxdir = tdxdir

    # 寻找文件路径
    def find_path(self, stock=None, subdir='lday', ext='day'):
        paths = [
            'vipdoc/sz/%s/sz%s.%s' % (subdir, stock, ext),
            'vipdoc/sh/%s/sh%s.%s' % (subdir, stock, ext),
        ]
        
        for p in paths:
            path = os.path.join(self.tdxdir, p)
            if os.path.exists(path):
                return path

        print('文件不存在')
        return None

    # 日线
    def daily(self, symbol=None):
        reader = TdxDailyBarReader()
        symbol = self.find_path(symbol)
        
        if not symbol is None:
            return reader.get_df(symbol)

        return None

    # 1分钟线
    def minbar(self, symbol=None):
        symbol = self.find_path(symbol, subdir='minline', ext='lc1')
        symbol = self.find_path(symbol, subdir='minline', ext='1') if not symbol else symbol
        reader = TdxLCMinBarReader()

        if not symbol is None:
            return reader.get_df(symbol)

        return None

    # 5分钟线
    def fzline(self, symbol=None):
        symbol = self.find_path(symbol, subdir='fzline', ext='lc5')
        symbol = self.find_path(symbol, subdir='fzline', ext='5') if not symbol else symbol     
        reader = TdxLCMinBarReader()

        if not symbol is None:
            return reader.get_df(symbol)

        return None

    # 板块
    def block(self, group=False, custom=False):
        reader = BlockReader()
        symbol = os.path.join(self.tdxdir, 'block_zs.dat')

        if not symbol is None:
            return reader.get_df(symbol, group)

        return None     
    
    # 指数
    def index(self, symbol='incon.dat', group=False):
        reader = BlockReader()
        symbol = os.path.join(self.tdxdir, symbol)
        
        if not symbol is None:
            return reader.get_df(symbol, group)

        return None

# 扩展市场读取
class ExReader(Reader):
    """扩展市场读取"""

    def ExDaily(symbol=None):
        reader = TdxExHqDailyBarReader()
        symbol = self.find_path(symbol)

        if not symbol is None:
            return reader.get_df(symbol)

        return None

        
